@@ -21,4 +21,4 @@ class CFM(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default, min_value=0)
+        super(CFM, self).__init__(default, min_value=0)
