@@ -21,13 +21,4 @@ class Mean(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self):
-        XMLScalar.__init__(self)
-        self._description = dict(
-            default='For type "gaussian*", the mean of the Gaussian '
-                    'distribution from which noise values are drawn.'
-        )
-
-    def _set_value(self, value):
-        assert self._is_scalar(value)
-        assert value >= 0
-        XMLScalar._set_value(self, value)
+        super(Mean, self).__init__(min_value=0)
