@@ -21,9 +21,4 @@ class PatchRadius(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
-
-    def _set_value(self, value):
-        assert self._is_scalar(value)
-        assert value >= 0
-        XMLScalar._set_value(self, value)
+        super(PatchRadius, self).__init__(default)
