@@ -20,13 +20,5 @@ class Sunset(XMLScalar):
     _TYPE = 'sdf'
 
     def __init__(self, default=0):
-        XMLScalar.__init__(self, default)
-
-    def _set_value(self, value):
-        assert self._is_scalar(value), \
-            'Input value must be either a' \
-            ' float or an integer, provided={}'.format(
-                type(value))
-        assert value >= 0, \
-            'Value must be greater or equal to zero, provided={}'.format(value)
-        XMLScalar._set_value(self, value)
+        super(Sunset, self).__init__(
+            default, min_value=0)
